(function ($, Drupal, CKEDITOR) {
  'use strict';

  /**
   * @file
   * Defines ImcePrivate plugin for CKEditor.
   */

  CKEDITOR.plugins.add('imceprivate', {
    // Define commands and buttons
    init: function (editor) {
      // Image
      editor.addCommand('imceimageprivate', {
        exec: CKEDITOR.imceprivate.imageDialogPrivate
      });
      editor.ui.addButton('ImceImagePrivate', {
        label: CKEDITOR.imceprivate.imageLabel('private'),
        command: 'imceimageprivate',
        icon: editor.config.ImceImageIconPrivate
      });
      editor.addCommand('imceimagepublic', {
        exec: CKEDITOR.imceprivate.imageDialogPublic
      });
      editor.ui.addButton('ImceImagePublic', {
        label: CKEDITOR.imceprivate.imageLabel('public'),
        command: 'imceimagepublic',
        icon: editor.config.ImceImageIconPublic
      });
      // Link
      editor.addCommand('imcelinkprivate', {
        exec: CKEDITOR.imceprivate.linkDialogPrivate
      });
      editor.ui.addButton('ImceLinkPrivate', {
        label: CKEDITOR.imceprivate.linkLabel('private'),
        command: 'imcelinkprivate',
        icon: editor.config.ImceLinkIconPrivate
      });
      editor.addCommand('imcelinkpublic', {
        exec: CKEDITOR.imceprivate.linkDialogPublic
      });
      editor.ui.addButton('ImceLinkPublic', {
        label: CKEDITOR.imceprivate.linkLabel('public'),
        command: 'imcelinkpublic',
        icon: editor.config.ImceLinkIconPublic
      });
    }
  });

  /**
   * Global container for helper methods.
   */
  CKEDITOR.imceprivate = CKEDITOR.imceprivate || {

    /**
     * Returns image button label.
     */
    imageLabel: function (scheme) {
      return Drupal.t('Insert ' + scheme + ' images using Imce File Manager');
    },

    /**
     * Opens Imce for inserting private images into CKEditor.
     */
    imageDialogPrivate: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'image', 'private');
    },

    /**
     * Opens Imce for inserting public images into CKEditor.
     */
    imageDialogPublic: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'image', 'public');
    },

    /**
     * Returns link button label.
     */
    linkLabel: function (scheme) {
      return Drupal.t('Insert ' + scheme + ' file links using Imce File Manager');
    },

    /**
     * Opens Imce for inserting private links into CKEditor.
     */
    linkDialogPrivate: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'link', 'private');
    },

    /**
     * Opens Imce for inserting public links into CKEditor.
     */
    linkDialogPublic: function (editor) {
      return CKEDITOR.imceprivate.openDialog(editor, 'link', 'public');
    },

    /**
     * Opens Imce for inserting images or links into CKEditor.
     */
    openDialog: function (editor, type, scheme) {
      var width = Math.min(1000, parseInt(screen.availWidth * 0.8));
      var height = Math.min(800, parseInt(screen.availHeight * 0.8));
      var url = CKEDITOR.imceprivate.url('sendto=CKEDITOR.imce.sendto&type=' + type + '&ck_id=' + encodeURIComponent(editor.name), scheme);
      editor.popup(url, width, height);
    },

    /**
     * Returns Imce url.
     */
    url: function (query, scheme) {
      var url = Drupal.url('imce');
      if (scheme) {
        url += '/' + scheme;
      }
      if (query) {
        url += (url.indexOf('?') === -1 ? '?' : '&') + query;
      }
      return url;
    },

  };

})(jQuery, Drupal, CKEDITOR);
