<?php

namespace Drupal\imce_private\Plugin\CKEditorPlugin;

use Drupal\ckeditor\CKEditorPluginBase;
use Drupal\editor\Entity\Editor;

/**
 * Defines the "imceprivate" plugin.
 *
 * @CKEditorPlugin(
 *   id = "imceprivate",
 *   label = @Translation("ImcePrivate"),
 * )
 */
class ImcePrivate extends CKEditorPluginBase {
  use \Drupal\Core\StringTranslation\StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function getFile() {
    return drupal_get_path('module', 'imce_private') . '/js/plugins/ckeditor/imce.ckeditor.js';
  }

  /**
   * {@inheritdoc}
   */
  public function getButtons() {
    return [
      'ImceImagePrivate' => [
        'label' => $this->t('Insert private images using Imce File Manager'),
        'image' => $this->imageIconPrivate(),
      ],
      'ImceLinkPrivate' => [
        'label' => $this->t('Insert private file links using Imce File Manager'),
        'image' => $this->linkIconPrivate(),
      ],
      'ImceImagePublic' => [
        'label' => $this->t('Insert public images using Imce File Manager'),
        'image' => $this->imageIconPublic(),
      ],
      'ImceLinkPublic' => [
        'label' => $this->t('Insert public file links using Imce File Manager'),
        'image' => $this->linkIconPublic(),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getConfig(Editor $editor) {
    return [
      'ImceImageIconPrivate' => file_create_url($this->imageIconPrivate()),
      'ImceLinkIconPrivate' => file_create_url($this->linkIconPrivate()),
      'ImceImageIconPublic' => file_create_url($this->imageIconPublic()),
      'ImceLinkIconPublic' => file_create_url($this->linkIconPublic()),
    ];
  }

  /**
   * Returns private image icon path.
   */
  public function imageIconPrivate() {
    return drupal_get_path('module', 'imce_private') . '/js/plugins/ckeditor/icons/imceimage_private.png';
  }

  /**
   * Returns private link icon path.
   */
  public function linkIconPrivate() {
    return drupal_get_path('module', 'imce_private') . '/js/plugins/ckeditor/icons/imcelink_private.png';
  }

  /**
   * Returns public image icon path.
   */
  public function imageIconPublic() {
    return drupal_get_path('module', 'imce_private') . '/js/plugins/ckeditor/icons/imceimage_public.png';
  }

  /**
   * Returns public link icon path.
   */
  public function linkIconPublic() {
    return drupal_get_path('module', 'imce_private') . '/js/plugins/ckeditor/icons/imcelink_public.png';
  }

}
